# -*- coding: utf-8 -*- #
# Copyright 2021 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""The super-group for policy-intelligence CLI."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.calliope import base


@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
@base.DefaultUniverseOnly
@base.Hidden
class PolicyIntelligenceAlpha(base.Group):
  """A platform to help better understand, use, and manage policies at scale."""
  category = base.IDENTITY_AND_SECURITY_CATEGORY

  def Filter(self, context, args):
    """Enables User-Project override for this surface."""
    base.EnableUserProjectQuota()
    # TODO(b/190538573):  Determine if command group works with project number
    base.RequireProjectID(args)


@base.ReleaseTracks(base.ReleaseTrack.BETA)
@base.DefaultUniverseOnly
@base.Hidden
class PolicyIntelligenceBeta(base.Group):
  """A platform to help better understand, use, and manage policies at scale."""
  category = base.IDENTITY_AND_SECURITY_CATEGORY

  def Filter(self, context, args):
    """Enables User-Project override for this surface."""
    base.EnableUserProjectQuota()
    # TODO(b/190538573):  Determine if command group works with project number
    base.RequireProjectID(args)


@base.ReleaseTracks(base.ReleaseTrack.GA)
@base.DefaultUniverseOnly
class PolicyIntelligenceGA(base.Group):
  """A platform to help better understand, use, and manage policies at scale."""
  category = base.IDENTITY_AND_SECURITY_CATEGORY

  def Filter(self, context, args):
    """Enables User-Project override for this surface."""
    base.EnableUserProjectQuota()
    # TODO(b/190538573):  Determine if command group works with project number
    base.RequireProjectID(args)
