# -*- coding: utf-8 -*- #
# Copyright 2016 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Command for spanner databases ddl describe."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

import textwrap

from googlecloudsdk.api_lib.spanner import databases
from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.spanner import flags
from googlecloudsdk.command_lib.spanner import resource_args


# TODO(b/305722139) Change @base.DefaultUniverseOnly to
# @base.UniverseCompatible once b/305722139 is fixed.
# See go/gcloud-cli-running-tpc-tests.
@base.DefaultUniverseOnly
class Describe(base.ListCommand):
  """Describe the DDL for a Cloud Spanner database."""

  detailed_help = {
      'EXAMPLES':
          textwrap.dedent("""\
        To describe the DDL for a given Cloud Spanner database, run:

          $ {command} my-database-id --instance=my-instance-id
        """),
  }

  @staticmethod
  def Args(parser):
    """See base class."""
    resource_args.AddDatabaseResourceArg(parser, 'of which the ddl to describe')
    parser.display_info.AddCacheUpdater(None)
    parser.display_info.AddFormat('value(format("{0};\n"))')
    flags.IncludeProtoDescriptors(
        help_text=(
            'Include debug string of proto bundle descriptors in the output.'
            ' The output is information only and not meant to be parsed.'
        )
    ).AddToParser(parser)

  def Run(self, args):
    """This is what gets called when the user runs this command.

    Args:
      args: an argparse namespace. All the arguments that were provided to this
        command invocation.

    Returns:
      Some value that we want to have printed later.
    """
    return databases.GetDdlWithDescriptors(args.CONCEPTS.database.Parse(), args)
